package nckd.base.helper;

import kd.bos.dataentity.entity.DynamicObject;
import kd.bos.dataentity.entity.DynamicObjectCollection;
import kd.bos.orm.query.QCP;
import kd.bos.orm.query.QFilter;
import kd.bos.servicehelper.BusinessDataServiceHelper;
import org.apache.commons.lang3.ObjectUtils;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Map;
import java.util.stream.Collectors;


/**
 * 工具类
 * @author wanghaiwu_kd
 * @date 2025/04/23
 */
public class CommonHelperUtils {
    /**
     * 根据单据编号获取客户化配置
     * @param number
     * @return
     */
    public static Map<String, String> getCommonParams(String number){
        String selectField = "nckd_entryentity.nckd_key, nckd_entryentity.nckd_value";

        QFilter qFilter = new QFilter("number", QCP.equals, number);
        DynamicObject commonParam = BusinessDataServiceHelper.loadSingle("nckd_commonparams", selectField, qFilter.toArray());
        if (ObjectUtils.isEmpty(commonParam)) {
            return null;
        }

        DynamicObjectCollection entryentity = commonParam.getDynamicObjectCollection("nckd_entryentity");
        if(entryentity == null || entryentity.size() == 0){
            return null;
        }
        Map<String, String> mapentity = entryentity.stream().collect(Collectors.toMap(k -> k.getString("nckd_key"), v -> v.getString("nckd_value")));

        return mapentity;
    }

    /**
     * 获取日期最小时分，最大时分
     * @param date
     * @param isStart
     * @return
     * @throws ParseException
     */
    public static Date getCurDateForm(Date date, boolean isStart) throws ParseException {
        SimpleDateFormat shortformat = new SimpleDateFormat("yyyy-MM-dd");
        SimpleDateFormat longformat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        String dateStr = shortformat.format(date);
        String suffix = " 00:00:00";
        if (!isStart) {
            suffix = " 23:59:59";
        }

        return longformat.parse(dateStr + suffix);
    }
}
